@@ -24,6 +24,7 @@
 #include "mainwindow.h"
 #include "coord.h"
 #include "statswidget.h"
+#include "knavalbattle_version.h"
 
 int main(int argc, char** argv)
 {
@@ -35,10 +36,10 @@ int main(int argc, char** argv)
     migrate.setUiFiles(QStringList() << QStringLiteral("knavalbattleui.rc"));
     migrate.migrate();
 
-    KAboutData aboutData(QStringLiteral("knavalbattle"), i18n("Naval Battle"), QStringLiteral("2.1"), 
+    KAboutData aboutData(QStringLiteral("knavalbattle"), i18n("Naval Battle"), KNAVALBATTLE_VERSION_STRING,
         i18n("The KDE ship sinking game"), KAboutLicense::GPL, 
         i18n("(c) 2000-2005  Nikolas Zimmermann, Daniel Molkentin\n"
-              "(c) 2007 Paolo Capriotti"), QString(), QStringLiteral("http://games.kde.org/kbattleship") );
+              "(c) 2007 Paolo Capriotti"), QString(), QStringLiteral("https://kde.org/applications/games/org.kde.kbattleship") );
     
     aboutData.addAuthor(i18n("Paolo Capriotti"), i18n("Current maintainer"), QStringLiteral("p.capriotti@gmail.com"));
     aboutData.addAuthor(i18n("Nikolas Zimmermann"), i18n("Project Founder, GUI Handling, Client/Server"), QStringLiteral("wildfox@kde.org"));
